===================
Hadrian.Utils.Slugs
===================


Hadrian includes a slug package ``hadrian.utils.slugs``


Usage
=====

Go ahead and import the package::

    from hadrian.utils.slugs import *
    
Unique Slugify::

    unique_slugify(self, field_to_slugify, slug_field)